@@ -21,6 +21,8 @@ class AutoMangle(MangleFile):
         size_factor = 0.30
 
         if 0.25 <= self.aggressivity:
+            operations.append("increment")
+        if 0.30 <= self.aggressivity:
             operations.extend(("replace", "special_value"))
         if 0.50 <= self.aggressivity:
             operations.extend(("insert_bytes", "delete_bytes"))
