@@ -1,3 +1,4 @@
+from ptrace.six import b
 from ptrace.os_tools import RUNNING_WINDOWS
 from fusil.process.tools import runCommand, locateProgram
 from fusil.bytes_generator import BytesGenerator
@@ -18,7 +19,7 @@ def encodeUTF32(text):
     data = []
     for character in text:
         data.append( pack('I', ord(character)) )
-    return ''.join(data)
+    return b('').join(data)
 
 def quoteString(text):
     data = []
