@@ -13,7 +13,7 @@ class FusilConfig:
             self._parser.read([self.filename])
 
         # Fusil application options
-        self.fusil_max_memory = self.getint('fusil', 'max_memory', 100*1024*1024)
+        self.fusil_max_memory = self.getint('fusil', 'max_memory', 0)
         self.fusil_success_score = self.getfloat('fusil', 'success_score', 0.50)
         self.fusil_error_score = self.getfloat('fusil', 'error_score', -0.50)
         self.fusil_success = self.getint('fusil', 'success', 1)
