@@ -1,10 +1,8 @@
 from random import randint, choice
-from fusil.mangle_op import SPECIAL_VALUES
+from fusil.mangle_op import SPECIAL_VALUES, MAX_INCR
 from array import array
 from fusil.tools import minmax
 
-MAX_INCR = 32
-
 def createBitOffset(agent, datalen):
     min_offset = 0
     if agent.min_offset is not None:
