@@ -1,3 +1,4 @@
+from __future__ import with_statement
 from fusil.project_agent import ProjectAgent
 from os import fstat
 from stat import ST_SIZE
@@ -42,8 +43,8 @@ class MangleAgent(ProjectAgent):
 
     def writeData(self, filename, data):
         self.info("Generate file: %s" % filename)
-        output = open(filename, 'wb')
-        data.tofile(output)
+        with open(filename, 'wb') as output: 
+            data.tofile(output)
         return filename
 
     def createFilename(self, filename, file_index):
