@@ -1,25 +1,23 @@
-from fusil.error import FUSIL_ERRORS, writeError
-from logging import getLogger
+from ptrace.error import PTRACE_ERRORS, writeError
 
 class AgentList:
     def __init__(self):
         self.agents = []
 
     def append(self, agent):
-        if agent in self.agents:
+        if agent in self:
             raise KeyError("Agent %r already registred")
         self.agents.append(agent)
 
     def _destroy(self, agent):
         try:
-            agent.debug("Removed from agent list")
             agent.deactivate()
-            agent.unregister(False)
-        except FUSIL_ERRORS, error:
-            writeError(getLogger(), error, "AGENT DEINIT ERROR")
+        except PTRACE_ERRORS, error:
+            writeError(None, error, "Agent deinit error")
+        agent.unregister(False)
 
     def remove(self, agent, destroy=True):
-        if agent not in self.agents:
+        if agent not in self:
             return
         self.agents.remove(agent)
         if destroy:
@@ -27,8 +25,7 @@ class AgentList:
 
     def clear(self):
         while self.agents:
-            agent = self.agents[-1]
-            del self.agents[-1]
+            agent = self.agents.pop()
             self._destroy(agent)
 
     def __del__(self):
