@@ -28,13 +28,10 @@ class Mailbox:
             return
         self.messages.append(message)
 
-    def __len__(self):
-        return len(self.messages)
-
-    def pop(self):
-        message = self.messages[0]
-        del self.messages[0]   # FIXME: use collection.deque
-        return message
+    def popMessages(self):
+        messages = self.messages
+        self.messages = []
+        return messages
 
     def __repr__(self):
         agent = self.agent()
