@@ -62,7 +62,8 @@ class NetworkServer(ProjectAgent):
         self.clients.remove(client)
 
     def clientRead(self, client):
-        data = client.recvBytes()
+        # FIXME: use received bytes
+        client.recvBytes()
 
     def live(self):
         if not self.socket:
