@@ -1,13 +1,15 @@
 from fusil.network.tools import formatAddress
 from fusil.session_agent import SessionAgent
-from socket import error as socket_error, timeout as socket_timeout
-from fusil.error import formatError
+from socket import error as socket_error, timeout as socket_timeout, SHUT_RDWR
+from ptrace.error import formatError
+from weakref import ref as weakref_ref
 
 class ServerClientDisconnect(Exception):
     pass
 
 class ServerClient(SessionAgent):
-    def __init__(self, session, socket, address, family):
+    def __init__(self, session, server, socket, address, family):
+        self.server = weakref_ref(server)
         self.socket = socket
         self.address = address
         self.family = family
@@ -17,6 +19,7 @@ class ServerClient(SessionAgent):
         self.rx_bytes = 0
 
     def recvBytes(self, buffer_size=1024):
+        log_data_exchange = self.server().log_data_exchange
         datas = []
         while True:
             try:
@@ -30,12 +33,13 @@ class ServerClient(SessionAgent):
                     break
                 else:
                     self.close()
-                    return None
+                    break
             if not data:
                 break
             data_len = len(data)
             self.rx_bytes += data_len
-            self.debug("Read bytes: (%s) %r" % (data_len, data))
+            if log_data_exchange:
+                self.warning("Read bytes: (%s) %r" % (data_len, data))
             datas.append(data)
 
         if not datas:
@@ -43,20 +47,30 @@ class ServerClient(SessionAgent):
             return None
         return ''.join(datas)
 
-    def sendBytes(self, data, buffer_size=4096):
-        data_queue = data
-        while data_queue:
-            data = data_queue[:buffer_size]
-            self.tx_bytes += len(data)
-            self.debug("Send bytes: (%s) %r" % (len(data), data))
+    def sendBytes(self, data, buffer_size=None):
+        log_data_exchange = self.server().log_data_exchange
+        index = 0
+        while index < len(data):
+            if buffer_size:
+                chunk = data[index:index+buffer_size]
+            else:
+                chunk = data[index:]
+            if log_data_exchange:
+                self.warning("Send bytes: (%s) %r" % (len(chunk), chunk))
             try:
-                self.socket.send(data)
+                count = self.socket.send(chunk)
+                index += count
+                self.tx_bytes += count
             except socket_error, err:
                 self.warning("Send error: %s" % formatError(err))
                 self.close()
-            data_queue = data_queue[buffer_size:]
+                break
 
     def close(self, emit_exception=True):
+        if not self.socket:
+            return
+        self.info("Close socket")
+        self.socket.shutdown(SHUT_RDWR)
         self.socket.close()
         self.socket = None
         if emit_exception:
