@@ -1,3 +1,4 @@
+from ptrace.six import binary_type
 from fusil.xhost import xhostCommand
 from fusil.write_code import WriteCode
 from sys import executable, getfilesystemencoding, path as sys_path
@@ -41,7 +42,7 @@ def formatPath(value, cwd, cwd_bytes):
     cwd + u'b'
     """
     result = []
-    if isinstance(value, str):
+    if isinstance(value, binary_type):
         pattern = cwd_bytes
         replace = u'cwd_bytes'
     else:
@@ -354,7 +355,7 @@ class WriteReplayScript(WriteCode):
 
         need_cwd_bytes = False
         for value in itertools.chain(arguments, env.itervalues()):
-            if not isinstance(value, str):
+            if not isinstance(value, binary_type):
                 continue
             if cwd_bytes not in value:
                 continue
@@ -423,8 +424,8 @@ class WriteReplayScript(WriteCode):
         filename = session.createFilename("replay.py")
         self.createFile(filename, 0755)
         self.pythonImports()
-        self.setSysPath()
         self.globalVariables(process, config, cwd, arguments, env)
+        self.setSysPath()
         self.writeFunction('debug(message)', self.writeDebugFunction)
         self.writeFunction('parseOptions()', self.parseOptions)
         self.writeFunction('safetyConfirmation(uid, gid)', self.safetyConfirmation)
