@@ -16,7 +16,7 @@ else:
         RLIMIT_AS, RLIMIT_CORE, RLIMIT_NPROC, RLIMIT_CPU)
     try:
         from os import nice
-    except ImportError, err:
+    except ImportError:
         # PyPy doesn't have os.nice()
         def nice(level):
             pass
@@ -32,7 +32,7 @@ else:
             if change_hard:
                 # Change hard limit
                 hard = soft
-        except ValueError, err:
+        except ValueError:
             hard = -1
         setrlimit(key, (soft, hard))
         return soft
@@ -87,7 +87,7 @@ def displayProcessStatus(logger, status, prefix="Process"):
     else:
         logger.warning("%s exited with error code: %s" % (prefix, status))
 
-def runCommand(logger, command, stdin=False, stdout=True, options=None):
+def runCommand(logger, command, stdin=False, stdout=True, options=None, raise_error=True):
     """
     Run specified command:
      - logger is an object with a info() method
@@ -96,8 +96,9 @@ def runCommand(logger, command, stdin=False, stdout=True, options=None):
      - stdout: if value is False, use null device as stdout and stderr
        (default: keep stdout)
 
-    Raise RuntimeError on failure: if the exit code is not nul
-    or if the process is killed by a signal.
+    Raise RuntimeError on failure: if the exit code is not nul or if the
+    process is killed by a signal. If raise_error=False, return the status and
+    don't raise RuntimeError if status is not nul.
     """
     if isinstance(command, (str, unicode)):
         command_str = repr(command)
@@ -130,6 +131,8 @@ def runCommand(logger, command, stdin=False, stdout=True, options=None):
         stdin_file.close()
     if stdout_file:
         stdout_file.close()
+    if not raise_error:
+        return status
     if not status:
         return
     if status < 0:
