@@ -3,15 +3,24 @@ from weakref import ref as weakref_ref
 from fusil.score import scoreLogFunc
 
 class ProjectAgent(Agent):
-    def __init__(self, project, name, mta=None):
+    def __init__(self, project, name, mta=None, application=None):
         if not mta:
             mta = project.mta()
         Agent.__init__(self, name, mta)
         self.project = weakref_ref(project)
+        if not application:
+            application = project.application()
+        self.application = weakref_ref(application)
         if project is not self:
             self.score_weight = 1.0
             self.register()
 
+    def session(self):
+        project = self.project()
+        if not project:
+            return None
+        return project.session
+
     def register(self):
         self.project().registerAgent(self)
 
