@@ -25,6 +25,7 @@ class SessionDirectory(SessionAgent, Directory):
         Directory.__init__(self, directory)
         SessionAgent.__init__(self, session, "directory:%s" % basename(self.directory))
         self.rename_parts = []
+        self.rename_set = set()
 
     def init(self):
         self.info("Create the directory: %s" % self.directory)
@@ -122,5 +123,9 @@ class SessionDirectory(SessionAgent, Directory):
             self.info("Normalize the session name part %r: %r" % (orig_part, part))
 
         # Store the name part
+        if part in self.rename_set:
+            # skip duplicates
+            return
+        self.rename_set.add(part)
         self.rename_parts.append(part)
 
