@@ -51,9 +51,16 @@ def makeFilename(text):
     >>> makeFilename('Fatal error!')
     'fatal_error'
     """
-    text = text.lower()
-    text = re.sub('[^a-z_-]', '_', text)
-    text = re.sub('_{2,}', '_', text)
-    text = re.sub('_$', '', text)
+    if isinstance(text, unicode):
+        text = text.lower()
+        text = re.sub(u'[^a-z_-]', '_', text)
+        text = re.sub(u'_{2,}', '_', text)
+        text = re.sub(u'_$', '', text)
+    else:
+        # byte string
+        text = text.lower()
+        text = re.sub('[^a-z_-]', '_', text)
+        text = re.sub('_{2,}', '_', text)
+        text = re.sub('_$', '', text)
     return text
 
