@@ -1,9 +1,7 @@
-import codecs
 from os import chmod
 
 class WriteCode:
-    def __init__(self, charset="ASCII"):
-        self.charset = charset
+    def __init__(self):
         self.indent = u' ' * 4
         self.base_level = 0
 
@@ -11,7 +9,7 @@ class WriteCode:
         self.output = stream
 
     def createFile(self, filename, mode=None):
-        self.output = codecs.open(filename, 'w', self.charset)
+        self.output = open(filename, 'w')
         if mode:
             chmod(filename, mode)
 
@@ -21,11 +19,8 @@ class WriteCode:
         self.output.close()
         self.output = None
 
-    def _writeLine(self, line):
-        print >>self.output, line
-
     def emptyLine(self):
-        self._writeLine('')
+        self.output.write("\n")
 
     def addLevel(self, delta):
         level = self.base_level
@@ -42,5 +37,5 @@ class WriteCode:
 
     def write(self, level, text):
         line = self.indentLine(level, text)
-        self._writeLine(line)
+        self.output.write(line + "\n")
 
